@@ -118,6 +118,9 @@ django.jQuery(function ($) {
     const inline = arg[0];
 
     inline.addEventListener("dragstart", function (e) {
+      // Only handle events from [draggable] elements
+      if (!e.target.closest("h3[draggable]")) return;
+
       // window.__fs_dragging = inline;
       window.__fs_dragging = e.target.closest(".inline-related");
       window.__fs_dragging.classList.add("fs-dragging");
@@ -281,7 +284,7 @@ django.jQuery(function ($) {
 
     select.className = "inline_move_to_region";
     select.value = regionInput.val();
-    $inline.find("> h3").append(select);
+    $inline.find("> h3 .inline_label").after(select);
 
     select.addEventListener("change", function () {
       $inline.attr("data-region", select.value);
@@ -489,6 +492,14 @@ django.jQuery(function ($) {
         this.checked
       );
       LS.set("collapseAll", this.checked);
+
+      if (this.checked) {
+        $(".order-machine .inline-related:not(.empty-form) .errorlist").each(
+          function uncollapseInvalidFieldsets() {
+            this.closest(".inline-related").classList.remove("collapsed");
+          }
+        );
+      }
     });
     collapseAllInput.attr("checked", LS.get("collapseAll")).trigger("change");
   })();
